#
# spec file for package wayshot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'

Name:           wayshot
Version:        1.3.1
Release:        2.1
Summary:        Screenshot tool for wlroots based compositors
License:        (0BSD OR MIT OR Apache-2.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR MIT OR Zlib) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND BSD-3-Clause AND ISC AND MIT AND Zlib AND BSD-2-Clause
Group:          Productivity/Graphics/Other
URL:            https://github.com/waycrate/wayshot
Source0:        https://github.com/waycrate/wayshot/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
%if 0%{?suse_version} >= 1500
BuildRequires:  cargo-packaging
%else
BuildRequires:  cargo
%endif
BuildRequires:  zstd

%description
A screenshot tool for wlroots based compositors implementing zwlr_screencopy_v1

%prep
%autosetup -a1

%build
export CARGO_HOME=$PWD/.cargo
export CARGO_TARGET_DIR=$PWD/target
ls -la $CARGO_HOME
pushd wayshot
%if 0%{?suse_version} >= 1500
RUSTFLAGS=%{rustflags} %{cargo_build}
%else
RUSTFLAGS=%{rustflags} cargo build --offline --release
%endif
popd

%install
# cargo install does not work with cached cargo home
install -D -d -m 0755 %{buildroot}%{_bindir}
install -m 0755 -t %{buildroot}%{_bindir}/ %{_builddir}/%{name}-%{version}/target/release/wayshot

%files
%{_bindir}/wayshot
%license LICENSE
%doc README.md

%changelog
* Thu Aug 22 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Update vendor tarball and use cargo home cache
* Mon Dec 18 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Remove sed line
* Mon Dec 18 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Remove cargo_config
- Update to version 1.3.1:
  * New features
  - CLI fuzzy selector (--chooseoutput) for screenshots
  * Improvements
  - Switch log crate with tracing and parallelize image alterations
  - Moved multi-monitor logic from wayshot to libwayshot
  - Remove uneeded resizes and rotations of image buffers
  - Deprecate xdpw fork in favor of the luminous portal
  - Update wayland crates
- Note that libwayshot contains breaking changes and improvements
  as well but will not be mentioned here since this is wayshot, the cli.
* Tue Aug 29 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove cargotoml param in _service.
- Update vendored dependencies.
* Mon Aug 21 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Use upstream source tarball instead of generating through service.
- Update vendored dependencies.
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Readd accidentally removed vendored deps.
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Mon Jul  3 2023 socvirnyl.estela@gmail.com
- Update to version 1.3.0:
  * [refactor] use libwayshot for shm
  * [docs] Update documentation
  * [feat] Qoi image format supported
  * [feat] Multi-output transform handling
  * [docs] Remove known bugs section
  * [fix] debug and stdout flags should conflict
  * [deps] Update dependencies
  * [Feat] Multi-output composited screenshots
  * [feat] Record output geometry transforms
  * [update] Reduce number of roundtrips in get_all_outputs
  * [feat] Add nix flake
  * [chore] Update xdg-desktop-portal-wlr submodule
  * [fix] Incorrect docs dir
  * [feature] Split backend into libwayshot
  * [feature] Custom XDPW implementation using wayshot
  * [update] Upgrade to wayland-rs 0.30.0
  * [docs] Update readme to accomodate https://github.com/waycrate/wayshot/pull/35
  * [feature] Parse slurp's default geometry output format
  * [deps] Remove unused dependency
  * [feature] added 10-bit back buffer support
  * [contrib/pkgbuild/bin] Remove man pages
  * [contrib/pkgbuild/bin] bump version
* Wed Jun  7 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies to fix CVE bnc#1212010
* Wed Sep 21 2022 socvirnyl.estela@gmail.com
- Update to version 1.2.2:
  * [bump] 1.2.2
  * [clippy] Remove PartialEq, Eq warning
  * [build.rs] Properly gzip the scdoc output
  * [update] ignore scdoc output files
  * [rustfmt] Fix formatting build.rs
  * [contrib/pkgbuild/bin] Update wayshot version
  * [bump] 1.2.1
  * [build.rs] Fix scdoc parent stdio inheritance
  * [contrib/pkgbuild/bin] Update wayshot version
  * [bump] 1.2.0
  * [chore] Bump dependencies
  * [BuildSystem]Don't depend on system shell for scd
  * [BuildSystem] Update install step
  * [contrib/pkgbuild/bin] Update makedeps
  * [contrib/pkgbuild] Fix man-page install paths
  * [docs/readme] Formattinge error
  * [Restructure] Move pkgbuilds into PKGBUILD
  * [contrib/pkgbuild/bin] Add man-page support
  * [contrib/pkgbuild/git]Add man-pages to git package
  * [BuildSystem] Improve man page installation
  * [contrib/pkgbuild/git] Add scdoc to makedeps
  * [build.rs] Binary existence check
  * [workflow] doc generation
  * [docs]Introduce scdoc generation in rust build sys
  * [chore] Cargo.lock
  * [contrib/pkgbuild/bin] update pkgbuild version
  * [backend.rs] PPM optimize performance
  * [docs/readme] color picker example
* Thu Aug  4 2022 William Brown <william.brown@suse.com>
- bsc#1182059 - CVE-2021-21299 - hyper request smuggling
* Thu Jul 21 2022 socvirnyl.estela@gmail.com
- Update to version 1.1.9:
  * [backend.rs] Add support for ppm rendering.
  * [bump] 1.1.8
  * [region-capture] out of bounds detection added
  * [update] add output dimension detection
  * [update] remove smithay dependency for faster builds
  * [push] .editorconfig
  * [update] memfd_create - add freebsd to target_os
  * [update] Readme.md
  * [chore] Cargo.lock
  * [update] replace xdg-output-handler with wl_output
* Sun May 29 2022 socvirnyl.estela@gmail.com
- Update to version 1.1.7~0:
  * [update] replace xdg-output-handler with wl_output
  * [update] nix deps bump and add repology to readme
  * [update] Sane error message on missing scrcpy.
  * [optimize dependencies] - Patch by jirutka
  * [update] Workflow.
  * [update] Bump dependencies.
  * [update] Readme
  * [update] Remove testing code.
  * [update] Fixes
  * [update] Add workflow.
- Use zstd compression :)
* Tue May 17 2022 socvirnyl.estela@gmail.com
- Update to version 1.1.5~1:
  * [update] Sane error message on missing scrcpy.
  * [optimize dependencies] - Patch by jirutka
  * [update] Workflow.
  * [update] Bump dependencies.
  * [update] Readme
  * [update] Remove testing code.
  * [update] Fixes
  * [update] Add workflow.
  * [update] fix readme
  * [update] Readme.
* Wed Mar 16 2022 socvirnyl.estela@gmail.com
- Update to version 1.1.5~0:
  * [update] Workflow.
  * [update] Bump dependencies.
  * [update] Readme
  * [update] Remove testing code.
  * [update] Fixes
  * [update] Add workflow.
  * [update] fix readme
  * [update] Readme.
  * [update]opensuse bin. Thanks to uncomfyhalomacro.
  * [update] shm.rs, bug fix
* Fri Mar 11 2022 socvirnyl.estela@gmail.com
- Update to version 1.1.5:
  * [update] Remove testing code.
  * [update] Fixes
  * [update] Add workflow.
  * [update] fix readme
  * [update] Readme.
  * [update]opensuse bin. Thanks to uncomfyhalomacro.
  * [update] shm.rs, bug fix
  * [update] Väinö Mäkelä, Replace unneeded roundtrip calls with dispatch
  * [bump] Version updates
  * [update] conflict with bin package
* Fri Mar 11 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Remove some reduntant Requires
- Remove not needed BuildRequires
* Fri Feb 25 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec
